summaryrefslogtreecommitdiffhomepage
path: root/src/external/stb_image_resize.h
diff options
context:
space:
mode:
authorRay <[email protected]>2019-04-23 16:01:18 +0200
committerRay <[email protected]>2019-04-23 16:01:18 +0200
commit372d77957fdc73991dca3f406c71a2c9a24b9e03 (patch)
tree66a973cb01758f7cf9ad6eca57d739a0a0cd4769 /src/external/stb_image_resize.h
parent958bf43eac6a71815c2815000b54e40d46e6c419 (diff)
downloadraylib-372d77957fdc73991dca3f406c71a2c9a24b9e03.tar.gz
raylib-372d77957fdc73991dca3f406c71a2c9a24b9e03.zip
Update STB libraries to latest version
Diffstat (limited to 'src/external/stb_image_resize.h')
-rw-r--r--src/external/stb_image_resize.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/external/stb_image_resize.h b/src/external/stb_image_resize.h
index 031ca99d..4f6ad35e 100644
--- a/src/external/stb_image_resize.h
+++ b/src/external/stb_image_resize.h
@@ -1,4 +1,4 @@
/* stb_image_resize - v0.95 - public domain image resizing
by Jorge L Rodriguez (@VinoBS) - 2014
http://github.com/nothings/stb
@@ -159,6 +159,7 @@
Nathan Reed: warning fixes
REVISIONS
+ 0.96 (2019-03-04) fixed warnings
0.95 (2017-07-23) fixed warnings
0.94 (2017-03-18) fixed warnings
0.93 (2017-03-03) fixed bug with certain combinations of heights
@@ -193,6 +194,7 @@ typedef uint16_t stbir_uint16;
typedef uint32_t stbir_uint32;
#endif
+#ifndef STBIRDEF
#ifdef STB_IMAGE_RESIZE_STATIC
#define STBIRDEF static
#else
@@ -202,7 +204,7 @@ typedef uint32_t stbir_uint32;
#define STBIRDEF extern
#endif
#endif
-
+#endif
//////////////////////////////////////////////////////////////////////////////
//
@@ -2324,8 +2326,9 @@ static int stbir__resize_allocated(stbir__info *info,
if (alpha_channel < 0)
flags |= STBIR_FLAG_ALPHA_USES_COLORSPACE | STBIR_FLAG_ALPHA_PREMULTIPLIED;
- if (!(flags&STBIR_FLAG_ALPHA_USES_COLORSPACE) || !(flags&STBIR_FLAG_ALPHA_PREMULTIPLIED))
+ if (!(flags&STBIR_FLAG_ALPHA_USES_COLORSPACE) || !(flags&STBIR_FLAG_ALPHA_PREMULTIPLIED)) {
STBIR_ASSERT(alpha_channel >= 0 && alpha_channel < info->channels);
+ }
if (alpha_channel >= info->channels)
return 0;
@@ -1,4 +1,4 @@
-/* stb_image_resize - v0.95 - public domain image resizing
+/* stb_image_resize - v0.96 - public domain image resizing
by Jorge L Rodriguez (@VinoBS) - 2014
http://github.com/nothings/stb